/*
 * Problem    : pairs
 * Author     : Daniel Neiter
 * Language   : C++
 * Compiler   : MS Visual C++ 2008 Express Edition
 * Algorithm  : Divide & conquer algorithm based on sorting points by polar angles
 * Complexity : O(N^2*log(N)) in the worst case
 */

#include <cstdio>
#include <algorithm>

using namespace std;

const char *infile="pairs.dat";
const char *outfile="pairs.sol";

const int maxN=2500;

struct point {
     int x,y;
     int ind,color;
     point() {}
     point(int x,int y):x(x),y(y) {}
     bool operator<(const point &p)const {return x<p.x||x==p.x&&y<p.y;}
     point operator-(const point &p)const {return point(x-p.x,y-p.y);}
     int operator*(const point &p)const {return x*p.y-p.x*y;}
};

point pt[2*maxN];
FILE *ofs;

struct PolarComper {
     point c;
     PolarComper(const point &c):c(c) {}
     bool operator()(const point &p1,const point &p2)const {return (p1-c)*(p2-c)>0;}
};

#define ABS(x) ((x)>0?(x):-(x))

inline void WritePair(const point &p1,const point &p2) {
     if(p1.color==1)fprintf(ofs,"%d %d\n",p1.ind,p2.ind);
     else fprintf(ofs,"%d %d\n",p2.ind,p1.ind);
}

void solve(int b,int e) {
     int best=b,i;
     if(b>=e)return;
     for(i=b;i<e;++i)
	  if(pt[i]<pt[best])best=i;
     swap(pt[b],pt[best]);
     sort(pt+b+1,pt+e,PolarComper(pt[b]));
     int sum=0,divp=10*maxN;
     for(i=b+1;i<e;++i) {
	  if(sum==0&&pt[b].color!=pt[i].color) {
	       if(ABS(divp-(b+e)/2)>ABS(i-(b+e)/2))divp=i;
	  }
	  sum+=pt[i].color;
     }
     WritePair(pt[b],pt[divp]);
     solve(b+1,divp);
     solve(divp+1,e);
}

int main() {
     int n,i,tests;
     FILE *ifs=fopen(infile,"r");
     ofs=fopen(outfile,"w");

     for(fscanf(ifs,"%d",&tests);tests;--tests) {
	  fscanf(ifs,"%d",&n);
	  for(i=0;i<n;i++) {
	       fscanf(ifs,"%d%d",&pt[i].x,&pt[i].y);
	       pt[i].color=1;
	       pt[i].ind=i+1;
	  }
	  for(i=0;i<n;i++) {
	       fscanf(ifs,"%d%d",&pt[i+n].x,&pt[i+n].y);
	       pt[i+n].color=-1;
	       pt[i+n].ind=i+1;
	  }
	  solve(0,2*n);
     }

     fclose(ifs);
     fclose(ofs);
     return 0;
}
