#include <iostream>
#include <vector>
#include <algorithm>
#include <cassert>
#include <cmath>
#include <queue>
#include <set>
#include <cstdio>

using namespace std;

#define pii pair<int,int>
#define rep(i,n) for(int i=0;i<n;++i)
#define X first
#define Y second

    FILE *fin = fopen("pairs.dat", "r");
    FILE *fout = fopen("pairs.sol", "w");

int divisor;

struct point
{
    int x, y;
    int ind;
    
    inline point() { }
    
    inline point(int _x, int _y) {
        x = _x; y = _y;
    }
    
    inline int color () {
        return ind < divisor ? 1 : -1;
    }
};

bool operator<(point a, point b)
{
    return (a.x == b.x && a.y < b.y) || (a.x < b.x);
}

point operator- (point a, point b) {
    return point(a.x-b.x, a.y-b.y);
}

long long cprod(point a, point b) {
    return a.x*b.y - a.y*b.x;
}

long long dprod(point a, point b) {
    return a.x*b.x + a.y*b.y;
}

vector<point> read_data() {
    vector<point> p;
    int n;
    fscanf(fin, "%d", &n);
    divisor = n;
    n*=2;
    p.resize(n);
    rep(i,n) {
        fscanf(fin, "%d%d", &p[i].x, &p[i].y);
        p[i].ind = i;
    }
    return p;
}

void write_answer(vector<pii> &pairs) {
    if (pairs.size() == 0) {
        fprintf(fout, "-1\n");
    } else {
	 
	 rep(i,pairs.size()) {
	      if(pairs[i].X>=pairs.size())swap(pairs[i].X,pairs[i].Y);
            fprintf(fout, "%d %d\n", pairs[i].X+1, pairs[i].Y+1-pairs.size());
	 }
    }
}

vector<pii> solve_low_high(vector<point>& points) {
    int n = points.size();
    vector<bool> colored(n, 0);
    queue<pii> problems;
    vector<pii> pairs;
    
    problems.push(make_pair(0, n));
    while (!problems.empty()) {
        int l = problems.front().first;
        int r = problems.front().second;
        
        vector<int> hup, hdown;
        
        for (int i = l; i < r; ++i)
            if (!colored[i]) {
                while (hup.size() >= 2 && cprod( points[i] - points[hup[hup.size() - 2]], 
                                                 points[hup[hup.size() - 1]] - points[hup[hup.size() - 2]] ) >= 0)
                    hup.pop_back();
                hup.push_back(i);
            }
        
        for (int i = l; i < r; ++i)
            if (!colored[i]) {
                while (hdown.size() >= 2 && cprod( points[i] - points[hdown[hdown.size() - 2]], 
                                                   points[hdown[hdown.size() - 1]] - points[hdown[hdown.size() - 2]] ) <= 0)
                    hdown.pop_back();
                hdown.push_back(i);
            }
        
        bool found = false;
        for (int i = 0; i+1 < hup.size(); ++i)
            if (!colored[hup[i]] && !colored[hup[i+1]] && points[hup[i]].color() * points[hup[i+1]].color() < 0) {
                found = true;
                colored[hup[i]] = true;
                colored[hup[i+1]] = true;
                pairs.push_back(make_pair(points[hup[i]].ind, points[hup[i+1]].ind));
            }
        for (int i = 0; i+1 < hdown.size(); ++i)
            if (!colored[hdown[i]] && !colored[hdown[i+1]] && points[hdown[i]].color() * points[hdown[i+1]].color() < 0) {
                found = true;
                colored[hdown[i]] = true;
                colored[hdown[i+1]] = true;
                pairs.push_back(make_pair(points[hdown[i]].ind, points[hdown[i+1]].ind));
            }
        if (hup.size()>0 && hdown.size()>0 && hup.back() != hdown.back() && !colored[hup.back()] && !colored[hdown.back()] &&
            points[hup.back()].color() * points[hdown.back()].color() < 0) {
            found = true;
            colored[hup.back()] = true;
            colored[hdown.back()] = true;
            pairs.push_back(make_pair(points[hup.back()].ind, points[hdown.back()].ind));
        }
        
        if (!found) {
            problems.pop();
            int sum = 0;
            int d = -1;
            for (int i = l; i < r; ++i) 
                if (!colored[i]) {
                    sum += points[i].color();
                    if (sum == 0) {
                        d = i+1;
                        break;
                    }
                }
            
            if (d != -1) {            
            assert(sum == 0);
            if (d > l)
                problems.push(make_pair(l, d));
            if (r > d)
                problems.push(make_pair(d, r));
            }
        }
    }
    return pairs;
}

int main (int argc, char * const argv[]) {
    
    int tests;
    fscanf(fin, "%d", &tests);
    rep(i,tests) {
        vector<point> data = read_data();
        sort(data.begin(), data.end());
        
        vector<pii> pairs = solve_low_high(data );

        write_answer(pairs);
    }
    fclose(fin);
    fclose(fout);
    return 0;
}
